<?php

namespace App\Providers;

use Illuminate\Support\Facades\Route;
use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to your controller routes.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'App\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @return void
     */
    public function boot()
    {
        //

        parent::boot();
    }

    /**
     * Define the routes for the application.
     *
     * @return void
     */
    public function map()
    {
        $this->mapApiRoutes();

        $this->mapApiTestRoutes();

        $this->mapMockRoutes();

        $this->mapWebRoutes();

        // Register CRUD routes
        $this->mapAdminRoutes();

        //
    }

    /**
     * Define the "web" routes for the application.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {
        Route::middleware(['web', 'installer.isAlreadyInstalled'])
             ->namespace($this->namespace)
             ->group(base_path('routes/web.php'));
    }

    /**
     * Define the "api" routes for the application.
     *
     * These routes are typically stateless.
     *
     * @return void
     */
    protected function mapApiRoutes()
    {
        Route::prefix('api')
             ->middleware('api')
             ->namespace($this->namespace . '\Api')
             ->group(base_path('routes/api.php'));
    }

    /**
     * Define the "apitest" routes for the application.
     *
     * Should be disabled on production.
     *
     * @return void
     */
    protected function mapApiTestRoutes()
    {
        Route::prefix('apitest')
          ->middleware('api')
          ->namespace($this->namespace)
          ->group(base_path('routes/apitest.php'));
    }

    /**
     * Define the "mock" routes for the application.
     *
     * These routes are typically stateless.
     *
     * @return void
     */
    protected function mapMockRoutes()
    {
        Route::prefix('mock')
            ->middleware('api')
            ->namespace($this->namespace . '\Mock')
            ->group(base_path('routes/mock.php'));
    }

    /**
     * Define the "admin / CRUD" routes for the application.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapAdminRoutes()
    {
        Route::middleware(['web', 'installer.isAlreadyInstalled', 'admin', 'hasAnyPermission'])
            ->prefix('admin') // or use the prefix from CRUD config
            ->namespace($this->namespace . '\Admin')
            ->group(base_path('routes/admin.php'));
    }
}
